@@ -1,4 +1,4 @@
-/* $Id: mancala.h,v 1.1.1.1 1995/07/25 11:55:21 sverrehu Exp $ */
+/* $Id: mancala.h,v 1.2 2007-06-13 18:29:52 sverrehu Exp $ */
 #ifndef MANCALA_H
 #define MANCALA_H
 
@@ -34,7 +34,7 @@ typedef struct Board {
     StoneCount mancala[2];
 } Board;
 
-void       initGame(void);
+void       initGame(int stones_pr_hole);
 StoneCount getHole(Player player, int hole);
 StoneCount getMancala(Player player);
 int        legalMove(Player player, PMove move);
