@@ -87,13 +87,17 @@ int main(int argc, char *argv[])
 	       "\n");
 	return 1;
     }
-
     if (stones_pr_hole < 1) {
         fprintf(stderr,
                 "mancala: the number of stones per hole must be greater "
                 "than zero\n");
         return 1;
     }
+    if (maxPly[0] < 0 || maxPly[1] < 0) {
+        fprintf(stderr,
+                "mancala: max-ply must be no less than zero\n");
+        return 1;
+    }
     initGame(stones_pr_hole);
     player = 1;
     for (;;) {
@@ -114,7 +118,10 @@ int main(int argc, char *argv[])
 	if (!maxPly[player]) {
 	    move = &move2;
 	    for (;;) {
-		fgets(s, 80, stdin);
+		if (fgets(s, 80, stdin) == NULL) {
+                    printf("\nBye.\n");
+                    return 0;
+                }
 		move->hole = 'A' + (MAX_HOLES - 1) - toupper(s[0]);
 		if (legalMove(player, move))
 		    break;
